@@ -458,7 +458,7 @@ impl Output {
                     .as_ref()
                     .unwrap_or(&"None".to_string()),
                 self.args
-                    .barcodes_option
+                    .counted_barcodes_option
                     .as_ref()
                     .unwrap_or(&"None".to_string())
             )
